@@ -51,15 +51,9 @@ def generate_report(opts):
 
     # output.xml files
     output_names = []
-    # support "*.xml" of output files
-    if ( opts.output == "*.xml" ):
-        for item in os.listdir(path):
-            if os.path.isfile(item) and item.endswith('.xml'):
-                output_names.append(item)
-    else:
-        for curr_name in opts.output.split(","):
-            curr_path = os.path.join(path, curr_name)
-            output_names.append(curr_path)
+    for curr_name in opts.output.split(","):
+        curr_path = os.path.join(path, curr_name)
+        output_names.append(curr_path)
 
     # log.html file
     log_name = opts.log_name
@@ -75,10 +69,7 @@ def generate_report(opts):
     mt_time = datetime.now().strftime('%Y%m%d-%H%M%S')
 
     # Output result file location
-    if opts.metrics_report_name:
-        result_file_name = opts.metrics_report_name
-    else:
-        result_file_name = 'metrics-' + mt_time + '.html'
+    result_file_name = 'metrics-' + mt_time + '.html'
     result_file = os.path.join(path, result_file_name)
 
     # Read output.xml file
@@ -117,9 +108,9 @@ def generate_report(opts):
         <script src="https://cdn.datatables.net/buttons/1.5.2/js/buttons.print.min.js" type="text/javascript"></script>
 
         <style>
-        body {
+            body {
                 font-family: -apple-system,sans-serif;
-	            background-color: #737678;
+                background-color: #737678;
             }
 
             .sidenav {
@@ -129,7 +120,7 @@ def generate_report(opts):
                 z-index: 1;
                 top: 0;
                 left: 0;
-                background-color: #383c40;
+                background-color: #383C40;
                 overflow-x: hidden;
                 border-style: ridge;
             }
@@ -138,14 +129,13 @@ def generate_report(opts):
                 padding: 12px 10px 8px 12px;
                 text-decoration: none;
                 font-size: 18px;
-                color: white;
+                color: Black;
                 display: block;
-				background-color: #383C40;
+                background-color: #383C40;
             }
 
             .main {
                 padding-top: 10px;
-				padding-left: 5px;
             }
 
             @media screen and (max-height: 450px) {
@@ -175,7 +165,7 @@ def generate_report(opts):
                 background: #4CAF50!important;
             }
             .tile.tile-info {
-                background: #616161!important;
+                background: #009688!important;
             }
             .tile.tile-head {
                 background: #616161!important;
@@ -193,8 +183,8 @@ def generate_report(opts):
                 z-index: 9999;
                 background: url('https://upload.wikimedia.org/wikipedia/commons/b/b1/Loading_icon.gif')
                     50% 50% no-repeat rgb(249,249,249);
-
             }
+
         </style>
     </head>
     """
@@ -205,7 +195,7 @@ def generate_report(opts):
     icons_txt = """
     <div class="loader"></div>
     <div class="sidenav">
-        <a> <img src="%s" style="height:12vh;max-width:98%;"/> </a>
+        <a> <img src="%s" style="height:12vh;max-width:98%%;"/> </a>
         <a class="tablink" href="#" id="defaultOpen" onclick="openPage('dashboard', this, 'orange')"><i class="fa fa-dashboard"></i> Dashboard</a>
         <a class="tablink" href="#" onclick="openPage('suiteMetrics', this, 'orange'); executeDataTable('#sm',5)"><i class="fa fa-th-large"></i> Suite Metrics</a>
         <a class="tablink" href="#" onclick="openPage('testMetrics', this, 'orange'); executeDataTable('#tm',3)"><i class="fa fa-list-alt"></i> Test Metrics</a>
@@ -265,138 +255,138 @@ def generate_report(opts):
 
     dashboard_content = """
     <div class="tabcontent" id="dashboard">
-        <div id="stats_screenshot_area">
-        <div class="d-flex flex-column flex-md-row align-items-center p-5 mb-3 bg-light
-            border-bottom shadow-sm">
-            <h2 class="my-0 mr-md-auto font-weight-normal"><i class="fa fa-dashboard"></i> Dashboard</h2>
-            <nav class="my-2 my-md-0 mr-md-3" style="color:red">
-            <a class="p-2"><b style="color:black;">Execution Time: </b>%s h</a>
-            <a class="p-2"><b style="color:black;cursor: pointer;" data-toggle="tooltip" title=".xml file is created by">Generated By: </b>%s</a>
-            </nav>
-        </div>
 
-        <div class="row">
-            <div class="col-md-3"  onclick="openPage('suiteMetrics', this, '')" data-toggle="tooltip"
-                title="Click to view Suite metrics" style="cursor: pointer;">
-                <a class="tile tile-head">
-                    Suite
-                    <p style="font-size:12px">Statistics</p>
-                </a>
-            </div>
-            <div class="col-md-3">
-                <a class="tile tile-info">
-                    %s
-                    <p style="font-size:12px">Total</p>
-                </a>
-            </div>
-            <div class="col-md-3">
-                <a class="tile tile-pass">
-                    %s
-                    <p style="font-size:12px">Pass</p>
-                </a>
-            </div>
-            <div class="col-md-3">
-                <a class="tile tile-fail">
-                    %s
-                    <p style="font-size:12px">Fail</p>
-                </a>
-            </div>
-        </div>
+                    <div class="d-flex flex-column flex-md-row align-items-center p-1 mb-3 bg-light
+                        border-bottom shadow-sm">
+                      <h5 class="my-0 mr-md-auto font-weight-normal"><i class="fa fa-dashboard"></i> Dashboard</h5>
+                      <nav class="my-2 my-md-0 mr-md-3" style="color:red">
+                        <a class="p-2"><b style="color:black;">Execution Time: </b>%s h</a>
+                        <a class="p-2"><b style="color:black;cursor: pointer;" data-toggle="tooltip" title=".xml file is created by">Generated By: </b>%s</a>
+                      </nav>
+                    </div>
 
-        <div class="row">
-            <div class="col-md-3"  onclick="openPage('testMetrics', this, '')" data-toggle="tooltip"
-            title="Click to view Test metrics" style="cursor: pointer;">
-                <a class="tile tile-head">
-                    Test
-                    <p style="font-size:12px">Statistics</p>
-                </a>
-            </div>
-            <div class="col-md-3">
-                <a class="tile tile-info">
-                    %s
-                    <p style="font-size:12px">Total</p>
-                </a>
-            </div>
-            <div class="col-md-3">
-                <a class="tile tile-pass">
-                    %s
-                    <p style="font-size:12px">Pass</p>
-                </a>
-            </div>
-            <div class="col-md-3">
-                <a class="tile tile-fail">
-                    %s
-                    <p style="font-size:12px">Fail</p>
-                </a>
-            </div>
-        </div>
+                    <div class="row">
+                        <div class="col-md-3"  onclick="openPage('suiteMetrics', this, '')" data-toggle="tooltip"
+                            title="Click to view Suite metrics" style="cursor: pointer;">
+                            <a class="tile tile-head">
+                                Suite
+                                <p style="font-size:12px">Statistics</p>
+                            </a>
+                        </div>
+                        <div class="col-md-3">
+                            <a class="tile tile-info">
+                                %s
+                                <p style="font-size:12px">Total</p>
+                            </a>
+                        </div>
+                        <div class="col-md-3">
+                            <a class="tile tile-pass">
+                                %s
+                                <p style="font-size:12px">Pass</p>
+                            </a>
+                        </div>
+                        <div class="col-md-3">
+                            <a class="tile tile-fail">
+                                %s
+                                <p style="font-size:12px">Fail</p>
+                            </a>
+                        </div>
+                    </div>
 
-        <div class="row">
-            <div class="col-md-3"  onclick="openPage('keywordMetrics', this, '')" data-toggle="tooltip"
-                title="Click to view Keyword metrics" style="cursor: pointer;">
-                <a class="tile tile-head">
-                    Keyword
-                    <p style="font-size:12px">Statistics</p>
-                </a>
-            </div>
-            <div class="col-md-3">
-                <a class="tile tile-info">
-                    %s
-                    <p style="font-size:12px">Total</p>
-                </a>
-            </div>
-            <div class="col-md-3">
-                <a class="tile tile-pass">
-                    %s
-                    <p style="font-size:12px">Pass</p>
-                </a>
-            </div>
-            <div class="col-md-3">
-                <a class="tile tile-fail">
-                    %s
-                    <p style="font-size:12px">Fail</p>
-                </a>
-            </div>
-        </div>
+                    <div class="row">
+                        <div class="col-md-3"  onclick="openPage('testMetrics', this, '')" data-toggle="tooltip"
+                        title="Click to view Test metrics" style="cursor: pointer;">
+                            <a class="tile tile-head">
+                                Test
+                                <p style="font-size:12px">Statistics</p>
+                            </a>
+                        </div>
+                        <div class="col-md-3">
+                            <a class="tile tile-info">
+                                %s
+                                <p style="font-size:12px">Total</p>
+                            </a>
+                        </div>
+                        <div class="col-md-3">
+                            <a class="tile tile-pass">
+                                %s
+                                <p style="font-size:12px">Pass</p>
+                            </a>
+                        </div>
+                        <div class="col-md-3">
+                            <a class="tile tile-fail">
+                                %s
+                                <p style="font-size:12px">Fail</p>
+                            </a>
+                        </div>
+                    </div>
 
-        <hr></hr>
-        <div class="row">
-            <div class="col-md-4" style="background-color:white;height:280px;width:auto;border:groove;">
-                <span style="font-weight:bold">Suite Status:</span>
-                <div id="suiteChartID" style="height:250px;width:auto;"></div>
-            </div>
-            <div class="col-md-4" style="background-color:white;height:280px;width:auto;border:groove;">
-                <span style="font-weight:bold">Test Status:</span>
-                <div id="testChartID" style="height:250px;width:auto;"></div>
-            </div>
-            <div class="col-md-4" style="background-color:white;height:280px;width:auto;border:groove;">
-                <span style="font-weight:bold">Keyword Status:</span>
-                <div id="keywordChartID" style="height:250px;width:auto;"></div>
-            </div>
-        </div>
-        </div>
-        <hr></hr>
-        <div class="row">
-            <div class="col-md-12" style="background-color:white;height:450px;width:auto;border:groove;">
-                <span style="font-weight:bold">Top 10 Suite Performance(sec):</span>
-                <div id="suiteBarID" style="height:400px;width:auto;"></div>
-            </div>
-            <div class="col-md-12" style="background-color:white;height:450px;width:auto;border:groove;">
-                <span style="font-weight:bold">Top 10 Test Performance(sec):</span>
-                <div id="testsBarID" style="height:400px;width:auto;"></div>
-            </div>
-            <div class="col-md-12" style="background-color:white;height:450px;width:auto;border:groove;">
-                <span style="font-weight:bold">Top 10 Keywords Performance(sec):</span>
-                <div id="keywordsBarID" style="height:400px;width:auto;"></div>
-            </div>
-        </div>
-        <div class="row">
-        <div class="col-md-12" style="height:25px;width:auto;">
-            <p class="text-muted" style="text-align:center;font-size:9px">
-                <a href="https://github.com">Python-Library </a>
-            </p>
-        </div>
-        </div>
+                    <div class="row">
+                        <div class="col-md-3"  onclick="openPage('keywordMetrics', this, '')" data-toggle="tooltip"
+                            title="Click to view Keyword metrics" style="cursor: pointer;">
+                            <a class="tile tile-head">
+                                Keyword
+                                <p style="font-size:12px">Statistics</p>
+                            </a>
+                        </div>
+                        <div class="col-md-3">
+                            <a class="tile tile-info">
+                                %s
+                                <p style="font-size:12px">Total</p>
+                            </a>
+                        </div>
+                        <div class="col-md-3">
+                            <a class="tile tile-pass">
+                                %s
+                                <p style="font-size:12px">Pass</p>
+                            </a>
+                        </div>
+                        <div class="col-md-3">
+                            <a class="tile tile-fail">
+                                %s
+                                <p style="font-size:12px">Fail</p>
+                            </a>
+                        </div>
+                    </div>
+
+                    <hr></hr>
+                    <div class="row">
+                        <div class="col-md-4" style="background-color:white;height:280px;width:auto;border:groove;">
+                            <span style="font-weight:bold">Suite Status:</span>
+                            <div id="suiteChartID" style="height:250px;width:auto;"></div>
+                        </div>
+                        <div class="col-md-4" style="background-color:white;height:280px;width:auto;border:groove;">
+                            <span style="font-weight:bold">Test Status:</span>
+                            <div id="testChartID" style="height:250px;width:auto;"></div>
+                        </div>
+                        <div class="col-md-4" style="background-color:white;height:280px;width:auto;border:groove;">
+                            <span style="font-weight:bold">Keyword Status:</span>
+                            <div id="keywordChartID" style="height:250px;width:auto;"></div>
+                        </div>
+                    </div>
+
+                    <hr></hr>
+                    <div class="row">
+                        <div class="col-md-12" style="background-color:white;height:450px;width:auto;border:groove;">
+                            <span style="font-weight:bold">Top 10 Suite Performance(sec):</span>
+                            <div id="suiteBarID" style="height:400px;width:auto;"></div>
+                        </div>
+                        <div class="col-md-12" style="background-color:white;height:450px;width:auto;border:groove;">
+                            <span style="font-weight:bold">Top 10 Test Performance(sec):</span>
+                            <div id="testsBarID" style="height:400px;width:auto;"></div>
+                        </div>
+                        <div class="col-md-12" style="background-color:white;height:450px;width:auto;border:groove;">
+                            <span style="font-weight:bold">Top 10 Keywords Performance(sec):</span>
+                            <div id="keywordsBarID" style="height:400px;width:auto;"></div>
+                        </div>
+                    </div>
+                    <div class="row">
+                    <div class="col-md-12" style="height:25px;width:auto;">
+                        <p class="text-muted" style="text-align:center;font-size:9px">
+                            <a target="_blank" href="https://github.com"> Graph-Report </a>
+                        </p>
+                    </div>
+                    </div>
 
        <script>
         window.onload = function(){
