@@ -17,6 +17,13 @@ def parse_options():
         help='Display application version information'
     )
 
+    general.add_argument(
+        '--logo',
+        dest='logo',
+        default='https://i.ibb.co/9qBkwDF/Testing-Fox-Logo.png',
+        help="User logo (default: dummy image )"
+    )
+
     general.add_argument(
         '--ignorelib',
         dest='ignore',
@@ -67,12 +74,6 @@ def parse_options():
         help="Name of output.xml"
     )
 
-    general.add_argument(
-        '--logo',
-        dest='logo',
-        default='https://pngimage.net/wp-content/uploads/2018/06/graph-png-transparent-5.png',
-        help="Give the image url for the logo"
-    )
 
     args = parser.parse_args()
     return args
